@@ -39,7 +39,7 @@ def main(config: dict):
 		super_copy(f"{TEMPLATES_PATH}/shaped_3x3.png", f"{config['build_resource_pack']}/assets/{config['namespace']}/textures/font/shaped_3x3.png")
 
 	# If the manual cache is enabled and we have a cache file, load it
-	if config['cache_manual_pages'] and os.path.exists(config['manual_debug']):
+	if config['cache_manual_pages'] and os.path.exists(config['manual_debug']) and os.path.exists(f"{config['manual_path']}/font/manual.json"):
 		with super_open(config['manual_debug'], "r") as f:
 			book_content = json.load(f)
 
@@ -478,7 +478,7 @@ def main(config: dict):
 	# Add the model to the resource pack
 	from ..resource_pack.item_models import handle_item
 	handle_item(config, "manual", config['database']["manual"])
-	vanilla_model = {"parent": "item/handheld","textures": {"layer0": "item/written_book"},"overrides": [{ "predicate": { "custom_model_data": manual_cmd}, "model": f"{config['namespace']}:item/manual" }]}
+	vanilla_model = {"parent": "item/generated","textures": {"layer0": "item/written_book"},"overrides": [{ "predicate": { "custom_model_data": manual_cmd}, "model": f"{config['namespace']}:item/manual" }]}
 	vanilla_model = super_json_dump(vanilla_model).replace('{"','{ "').replace('"}','" }').replace(',"', ', "')
 	write_to_file(f"{config['build_resource_pack']}/assets/minecraft/models/item/written_book.json", vanilla_model)
 
